@@ -245,25 +245,29 @@ TCGAanalyze_Preprocessing <- function(
 #'  group1 <- TCGAquery_SampleTypes(colnames(dataBRCAcomplete), typesample = c("NT"))
 #'  group2 <- TCGAquery_SampleTypes(colnames(dataBRCAcomplete), typesample = c("TP"))
 #'
-#'  tabSurvKM <- TCGAanalyze_SurvivalKM(clinical_patient_Cancer,
-#'                                      dataBRCAcomplete,
-#'                                      Genelist = rownames(dataBRCAcomplete),
-#'                                      Survresult = FALSE,
-#'                                      p.cut = 0.4,
-#'                                      ThreshTop = 0.67,
-#'                                      ThreshDown = 0.33,
-#'                                      group1 = group1, # Control group
-#'                                      group2 = group2) # Disease group
+#'  tabSurvKM <- TCGAanalyze_SurvivalKM(
+#'     clinical_patient = clinical_patient_Cancer,
+#'     dataGE = dataBRCAcomplete,
+#'     Genelist = rownames(dataBRCAcomplete),
+#'     Survresult = FALSE,
+#'     p.cut = 0.4,
+#'     ThreshTop = 0.67,
+#'     ThreshDown = 0.33,
+#'     group1 = group1, # Control group
+#'     group2 = group2
+#'   ) # Disease group
 #'
 #'  # If the groups are not specified group1 == group2 and all samples are used
 #'  \dontrun{
-#'  tabSurvKM <- TCGAanalyze_SurvivalKM(clinical_patient_Cancer,
-#'                                      dataBRCAcomplete,
-#'                                      Genelist = rownames(dataBRCAcomplete),
-#'                                      Survresult = TRUE,
-#'                                      p.cut = 0.2,
-#'                                      ThreshTop = 0.67,
-#'                                      ThreshDown = 0.33)
+#'  tabSurvKM <- TCGAanalyze_SurvivalKM(
+#'    clinical_patient_Cancer,
+#'    dataBRCAcomplete,
+#'    Genelist = rownames(dataBRCAcomplete),
+#'    Survresult = TRUE,
+#'    p.cut = 0.2,
+#'     ThreshTop = 0.67,
+#'     ThreshDown = 0.33
+#'   )
 #' }
 TCGAanalyze_SurvivalKM <- function(
         clinical_patient,
@@ -287,18 +291,20 @@ TCGAanalyze_SurvivalKM <- function(
     colnames(dataCancer)  <- substr(colnames(dataCancer), 1, 12)
 
     cfu <- clinical_patient[clinical_patient[, "bcr_patient_barcode"] %in% substr(colnames(dataCancer), 1, 12), ]
+
     if ("days_to_last_followup" %in% colnames(cfu))
-        colnames(cfu)[grep("days_to_last_followup", colnames(cfu))] <-
-        "days_to_last_follow_up"
-    cfu <-  as.data.frame(subset(
-        cfu,
-        select = c(
-            "bcr_patient_barcode",
-            "days_to_death",
-            "days_to_last_follow_up",
-            "vital_status"
-        )
-    ))
+        colnames(cfu)[grep("days_to_last_followup", colnames(cfu))] <- "days_to_last_follow_up"
+
+    cfu <-  as.data.frame(
+        subset(
+            cfu,
+            select = c(
+                "bcr_patient_barcode",
+                "days_to_death",
+                "days_to_last_follow_up",
+                "vital_status"
+            )
+        ))
 
     # Set alive death to inf
     if (length(grep("alive", cfu$vital_status, ignore.case = TRUE)) > 0)
@@ -324,125 +330,128 @@ TCGAanalyze_SurvivalKM <- function(
     ngenes <- nrow(as.matrix(rownames(dataNormal)))
 
     # Evaluate each gene
-    tabSurv_Matrix <- plyr::adply(.data =1:length(rownames(dataNormal)),.margins = 1,.fun = function(i){
+    tabSurv_Matrix <- plyr::adply(
+        .data = 1:length(rownames(dataNormal)),
+        .margins = 1,
+        .fun = function(i){
 
-        mRNAselected <- as.matrix(rownames(dataNormal))[i]
-        mRNAselected_values <-  dataCancer[rownames(dataCancer) == mRNAselected, ]
-        mRNAselected_values_normal <- dataNormal[rownames(dataNormal) == mRNAselected, ]
-        if (all(mRNAselected_values == 0))  return(NULL) # All genes are 0
-        tabSurv_Matrix <- data.frame("mRNA" = mRNAselected)
+            mRNAselected <- as.matrix(rownames(dataNormal))[i]
+            mRNAselected_values <-  dataCancer %>% dplyr::filter(rownames(dataCancer) == mRNAselected) %>% as.numeric
+            mRNAselected_values_normal <- dataNormal %>% dplyr::filter(rownames(dataNormal) == mRNAselected) %>% as.numeric
+            if (all(mRNAselected_values == 0))  return(NULL) # All genes are 0
+            tabSurv_Matrix <- data.frame("mRNA" = mRNAselected)
 
-        # Get Thresh values for cancer expression
-        mRNAselected_values_ordered <- sort(mRNAselected_values, decreasing = TRUE)
-        mRNAselected_values_ordered_top <- as.numeric(quantile(as.numeric(mRNAselected_values_ordered), ThreshTop)[1])
-        mRNAselected_values_ordered_down <- as.numeric(quantile(as.numeric(mRNAselected_values_ordered), ThreshDown)[1])
+            # Get Thresh values for cancer expression
+            mRNAselected_values_ordered <- sort(mRNAselected_values, decreasing = TRUE)
+            mRNAselected_values_ordered_top <- as.numeric(quantile(as.numeric(mRNAselected_values_ordered), ThreshTop)[1])
+            mRNAselected_values_ordered_down <- as.numeric(quantile(as.numeric(mRNAselected_values_ordered), ThreshDown)[1])
 
-        mRNAselected_values_newvector <- mRNAselected_values
+            mRNAselected_values_newvector <- mRNAselected_values
 
-        if (!is.na(mRNAselected_values_ordered_top)) {
-            # How many samples do we have
-            numberOfSamples <- length(mRNAselected_values_ordered)
+            if (!is.na(mRNAselected_values_ordered_top)) {
+                # How many samples do we have
+                numberOfSamples <- length(mRNAselected_values_ordered)
 
-            # High group (above ThreshTop)
-            lastelementTOP <- max(which(
-                mRNAselected_values_ordered > mRNAselected_values_ordered_top
-            ))
+                # High group (above ThreshTop)
+                lastelementTOP <- max(which(
+                    mRNAselected_values_ordered > mRNAselected_values_ordered_top
+                ))
 
-            # Low group (below ThreshDown)
-            firstelementDOWN <-  min(
-                which(
-                    mRNAselected_values_ordered <= mRNAselected_values_ordered_down
+                # Low group (below ThreshDown)
+                firstelementDOWN <-  min(
+                    which(
+                        mRNAselected_values_ordered <= mRNAselected_values_ordered_down
+                    )
                 )
-            )
 
-            samples_top_mRNA_selected <- names(mRNAselected_values_ordered[1:lastelementTOP])
-            samples_down_mRNA_selected <- names(mRNAselected_values_ordered[firstelementDOWN:numberOfSamples])
+                samples_top_mRNA_selected <- names(mRNAselected_values_ordered[1:lastelementTOP])
+                samples_down_mRNA_selected <- names(mRNAselected_values_ordered[firstelementDOWN:numberOfSamples])
 
-            # Which samples are in the intermediate group (above ThreshLow and below ThreshTop)
-            samples_UNCHANGED_mRNA_selected <- names(mRNAselected_values_newvector[which((mRNAselected_values_newvector) > mRNAselected_values_ordered_down &
-                                                                                             mRNAselected_values_newvector < mRNAselected_values_ordered_top
-            )])
+                # Which samples are in the intermediate group (above ThreshLow and below ThreshTop)
+                samples_UNCHANGED_mRNA_selected <- names(mRNAselected_values_newvector[
+                    which((mRNAselected_values_newvector) > mRNAselected_values_ordered_down &  mRNAselected_values_newvector < mRNAselected_values_ordered_top
+                    )])
 
-            cfu_onlyTOP <- cfu_complete[cfu_complete[, "bcr_patient_barcode"] %in% samples_top_mRNA_selected, ]
-            cfu_onlyDOWN <- cfu_complete[cfu_complete[, "bcr_patient_barcode"] %in% samples_down_mRNA_selected, ]
-            cfu_onlyUNCHANGED <- cfu_complete[cfu_complete[, "bcr_patient_barcode"] %in% samples_UNCHANGED_mRNA_selected, ]
+                cfu_onlyTOP <- cfu_complete[cfu_complete[, "bcr_patient_barcode"] %in% samples_top_mRNA_selected, ]
+                cfu_onlyDOWN <- cfu_complete[cfu_complete[, "bcr_patient_barcode"] %in% samples_down_mRNA_selected, ]
+                cfu_onlyUNCHANGED <- cfu_complete[cfu_complete[, "bcr_patient_barcode"] %in% samples_UNCHANGED_mRNA_selected, ]
 
-            cfu_ordered <- NULL
-            cfu_ordered <- rbind(cfu_onlyTOP, cfu_onlyDOWN)
-            cfu <- cfu_ordered
+                cfu_ordered <- NULL
+                cfu_ordered <- rbind(cfu_onlyTOP, cfu_onlyDOWN)
+                cfu <- cfu_ordered
 
-            ttime <- as.numeric(cfu[, "days_to_death"])
+                ttime <- as.numeric(cfu[, "days_to_death"])
 
-            sum(status <- ttime > 0) # morti
-            deads_complete <- sum(status <- ttime > 0)
+                sum(status <- ttime > 0) # morti
+                deads_complete <- sum(status <- ttime > 0)
 
-            ttime_only_top <- cfu_onlyTOP[, "days_to_death"]
-            deads_top <- sum(ttime_only_top > 0)
+                ttime_only_top <- cfu_onlyTOP[, "days_to_death"]
+                deads_top <- sum(ttime_only_top > 0)
 
-            if (dim(cfu_onlyDOWN)[1] >= 1) {
-                ttime_only_down <- cfu_onlyDOWN[, "days_to_death"]
-                deads_down <- sum(ttime_only_down > 0)
-            } else {
-                deads_down <- 0
-            }
+                if (dim(cfu_onlyDOWN)[1] >= 1) {
+                    ttime_only_down <- cfu_onlyDOWN[, "days_to_death"]
+                    deads_down <- sum(ttime_only_down > 0)
+                } else {
+                    deads_down <- 0
+                }
 
-            tabSurv_Matrix[1, "Cancer Deaths"] <- deads_complete
-            tabSurv_Matrix[1, "Cancer Deaths with Top"] <- deads_top
-            tabSurv_Matrix[1, "Cancer Deaths with Down"] <- deads_down
-            tabSurv_Matrix[1, "Mean Normal"] <- mean(as.numeric(mRNAselected_values_normal))
-            dataCancer_onlyTop_sample <- dataCancer[, samples_top_mRNA_selected, drop = FALSE]
-            dataCancer_onlyTop_sample_mRNASelected <- dataCancer_onlyTop_sample[rownames(dataCancer_onlyTop_sample) == mRNAselected, ]
-            dataCancer_onlyDown_sample <- dataCancer[, samples_down_mRNA_selected, drop = FALSE]
-            dataCancer_onlyDown_sample_mRNASelected <- dataCancer_onlyDown_sample[rownames(dataCancer_onlyDown_sample) == mRNAselected, ]
-            tabSurv_Matrix[1, "Mean Tumor Top"] <- mean(as.numeric(dataCancer_onlyTop_sample_mRNASelected))
-            tabSurv_Matrix[1, "Mean Tumor Down"] <- mean(as.numeric(dataCancer_onlyDown_sample_mRNASelected))
+                tabSurv_Matrix[1, "Cancer Deaths"] <- deads_complete
+                tabSurv_Matrix[1, "Cancer Deaths with Top"] <- deads_top
+                tabSurv_Matrix[1, "Cancer Deaths with Down"] <- deads_down
+                tabSurv_Matrix[1, "Mean Normal"] <- mean(as.numeric(mRNAselected_values_normal))
+                dataCancer_onlyTop_sample <- dataCancer[, samples_top_mRNA_selected, drop = FALSE]
+                dataCancer_onlyTop_sample_mRNASelected <- dataCancer_onlyTop_sample[rownames(dataCancer_onlyTop_sample) == mRNAselected, ]
+                dataCancer_onlyDown_sample <- dataCancer[, samples_down_mRNA_selected, drop = FALSE]
+                dataCancer_onlyDown_sample_mRNASelected <- dataCancer_onlyDown_sample[rownames(dataCancer_onlyDown_sample) == mRNAselected, ]
+                tabSurv_Matrix[1, "Mean Tumor Top"] <- mean(as.numeric(dataCancer_onlyTop_sample_mRNASelected))
+                tabSurv_Matrix[1, "Mean Tumor Down"] <- mean(as.numeric(dataCancer_onlyDown_sample_mRNASelected))
 
-            ttime[!status] <- as.numeric(cfu[!status, "days_to_last_follow_up"])
-            ttime[which(ttime == -Inf)] <- 0
+                ttime[!status] <- as.numeric(cfu[!status, "days_to_last_follow_up"])
+                ttime[which(ttime == -Inf)] <- 0
 
-            ttime <- survival::Surv(ttime, status)
-            rownames(ttime) <- rownames(cfu)
-            legendHigh <- paste(mRNAselected, "High")
-            legendLow  <- paste(mRNAselected, "Low")
+                ttime <- survival::Surv(ttime, status)
+                rownames(ttime) <- rownames(cfu)
+                legendHigh <- paste(mRNAselected, "High")
+                legendLow  <- paste(mRNAselected, "Low")
 
-            tabSurv_pvalue <- tryCatch({
-                tabSurv <- survival::survdiff(ttime  ~ c(rep(
-                    "top", nrow(cfu_onlyTOP)
-                ), rep(
-                    "down", nrow(cfu_onlyDOWN)
-                )))
-                tabSurv_chis <- unlist(tabSurv)$chisq
-                tabSurv_pvalue <-
-                    as.numeric(1 - pchisq(abs(tabSurv$chisq), df = 1))
-            }, error = function(e) {
-                return(Inf)
-            })
-            tabSurv_Matrix[1, "pvalue"] <- tabSurv_pvalue
+                tabSurv_pvalue <- tryCatch({
+                    tabSurv <- survival::survdiff(ttime  ~ c(rep(
+                        "top", nrow(cfu_onlyTOP)
+                    ), rep(
+                        "down", nrow(cfu_onlyDOWN)
+                    )))
+                    tabSurv_chis <- unlist(tabSurv)$chisq
+                    tabSurv_pvalue <-
+                        as.numeric(1 - pchisq(abs(tabSurv$chisq), df = 1))
+                }, error = function(e) {
+                    return(Inf)
+                })
+                tabSurv_Matrix[1, "pvalue"] <- tabSurv_pvalue
 
-            if (Survresult == TRUE) {
-                titlePlot <- paste("Kaplan-Meier Survival analysis, pvalue = ",tabSurv_pvalue)
-                plot(
-                    survival::survfit(ttime ~ c(
-                        rep("low", nrow(cfu_onlyTOP)), rep("high", nrow(cfu_onlyDOWN))
-                    )),
-                    col = c("green", "red"),
-                    main = titlePlot,
-                    xlab = "Days",
-                    ylab = "Survival"
-                )
-                legend(
-                    100,
-                    1,
-                    legend = c(legendLow, legendHigh),
-                    col = c("green", "red"),
-                    text.col = c("green", "red"),
-                    pch = 15
-                )
-                print(tabSurv)
-            }
-        } #end if
-        tabSurv_Matrix
-    },.progress = "time") #end for
+                if (Survresult == TRUE) {
+                    titlePlot <- paste("Kaplan-Meier Survival analysis, pvalue = ",tabSurv_pvalue)
+                    plot(
+                        survival::survfit(ttime ~ c(
+                            rep("low", nrow(cfu_onlyTOP)), rep("high", nrow(cfu_onlyDOWN))
+                        )),
+                        col = c("green", "red"),
+                        main = titlePlot,
+                        xlab = "Days",
+                        ylab = "Survival"
+                    )
+                    legend(
+                        100,
+                        1,
+                        legend = c(legendLow, legendHigh),
+                        col = c("green", "red"),
+                        text.col = c("green", "red"),
+                        pch = 15
+                    )
+                    print(tabSurv)
+                }
+            } #end if
+            tabSurv_Matrix
+        },.progress = "time") #end for
 
     tabSurv_Matrix[tabSurv_Matrix == "-Inf"] <- 0
 
@@ -1417,9 +1426,13 @@ TCGAanalyze_EAcomplete <- function(TFname, RegulonList) {
 #' \dontrun{
 #' EAGenes <- get("EAGenes")
 #' RegulonList <- rownames(dataDEGsFiltLevel)
-#' ResBP <- TCGAanalyze_EA(GeneName="DEA genes Normal Vs Tumor",
-#'                            RegulonList,DAVID_BP_matrix,
-#'                            EAGenes,GOtype = "DavidBP")
+#' ResBP <- TCGAanalyze_EA(
+#'   GeneName="DEA genes Normal Vs Tumor",
+#'   RegulonList = RegulonList,
+#'   TableEnrichment = DAVID_BP_matrix,
+#'    EAGenes = EAGenes,
+#'    GOtype = "DavidBP"
+#'  )
 #'}
 TCGAanalyze_EA <- function (
         GeneName,
@@ -1833,9 +1846,9 @@ gaiaCNVplot <- function (calls,  threshold = 0.01) {
     rownames(Calls) <- NULL
     Chromo <- Calls[, grep("chr", colnames(calls), ignore.case = TRUE)]
     Gains <- apply(Calls, 1, function(x)
-            ifelse(x[grep("aberration", colnames(calls), ignore.case = TRUE)] == 1, x["score"], 0))
+        ifelse(x[grep("aberration", colnames(calls), ignore.case = TRUE)] == 1, x["score"], 0))
     Losses <- apply(Calls, 1, function(x)
-            ifelse(x[grep("aberration", colnames(calls), ignore.case = TRUE)] == 0, x["score"], 0))
+        ifelse(x[grep("aberration", colnames(calls), ignore.case = TRUE)] == 0, x["score"], 0))
     plot(
         Gains,
         ylim = c(-max(Calls[, "score"] + 2), max(Calls[, "score"] + 2)),
@@ -1968,70 +1981,53 @@ getAdjacencyBiogrid <- function(tmp.biogrid, names.genes = NULL) {
     return(mat.biogrid)
 }
 
-#' Get GDC samples with both DNA methylation (HM450K) and Gene expression data from
-#' GDC databse
+#' @title Get GDC primary tumors samples with both DNA methylation (HM450K) and Gene expression data
 #' @description
-#' For a given TCGA project it gets the  samples (barcode) with both DNA methylation and Gene expression data
-#' from GDC database
+#' For a given TCGA project it gets the  primary tumors samples (barcode) with both
+#' DNA methylation and Gene expression data from GDC database
 #' @param project A GDC project
 #' @param n Number of samples to return. If NULL return all (default)
-#' @param legacy Access legacy (hg19) or harmonized database (hg38).
 #' @return A vector of barcodes
 #' @export
 #' @examples
 #' # Get ACC samples with both  DNA methylation (HM450K) and gene expression aligned to hg19
-#' samples <- matchedMetExp("TCGA-UCS", legacy = TRUE)
-matchedMetExp <- function(project, legacy = FALSE, n = NULL) {
-    if (legacy) {
-        # get primary solid tumor samples: DNA methylation
-        message("Download DNA methylation information")
-        met450k <- GDCquery(
-            project = project,
-            data.category = "DNA methylation",
-            platform = "Illumina Human Methylation 450",
-            legacy = TRUE,
-            sample.type = c("Primary Tumor")
-        )
+#' samples <- matchedMetExp("TCGA-UCS")
+matchedMetExp <- function(
+        project,
+        n = NULL
+) {
 
-        # get primary solid tumor samples: RNAseq
-        message("Download gene expression information")
-        exp <- GDCquery(
-            project = project,
-            data.category = "Gene expression",
-            data.type = "Gene expression quantification",
-            platform = "Illumina HiSeq",
-            file.type  = "results",
-            sample.type = c("Primary Tumor"),
-            legacy = TRUE
-        )
-    } else {
-        # get primary solid tumor samples: DNA methylation
-        message("Download DNA methylation information")
-        met450k <- GDCquery(
-            project = project,
-            data.category = "DNA Methylation",
-            platform = "Illumina Human Methylation 450",
-            sample.type = c("Primary Tumor")
-        )
+    # get primary solid tumor samples: DNA methylation
+    message("Download DNA methylation information")
+    met450k <- GDCquery(
+        project = project,
+        data.category = "DNA Methylation",
+        platform = "Illumina Human Methylation 450",
+        sample.type = c("Primary Tumor")
+    )
 
-        # get primary solid tumor samples: RNAseq
-        message("Download gene expression information")
-        exp <- GDCquery(
-            project = project,
-            data.category = "Transcriptome Profiling",
-            data.type = "Gene Expression Quantification",
-            workflow.type = "HTSeq - Counts"
-        )
+    # get primary solid tumor samples: RNAseq
+    message("Download gene expression information")
+    exp <- GDCquery(
+        project = project,
+        data.category = "Transcriptome Profiling",
+        data.type = "Gene Expression Quantification",
+        workflow.type = "STAR - Counts"
+    )
 
-
-    }
-    met450k.tp <-  met450k$results[[1]]$cases
     # Get patients with samples in both platforms
-    exp.tp <-  exp$results[[1]]$cases
+    met450k_tp <- met450k$results[[1]]$cases
+    exp_tp <- exp$results[[1]]$cases
+
     patients <-
-        unique(substr(exp.tp, 1, 15)[substr(exp.tp, 1, 12) %in% substr(met450k.tp, 1, 12)])
-    if (!is.null(n))
+        substr(exp_tp, 1, 15)[
+            substr(exp_tp, 1, 15) %in% substr(met450k_tp, 1, 15)
+        ] |> unique()
+
+    if (!is.null(n)) {
         patients <- patients[1:n] # get only n samples
+    }
+
     return(patients)
 }
 
